.. image:: https://img.shields.io/pypi/v/jaraco.collections.svg
   :target: https://pypi.io/project/jaraco.collections

.. image:: https://img.shields.io/pypi/pyversions/jaraco.collections.svg

.. image:: https://img.shields.io/travis/jaraco/jaraco.collections/master.svg
   :target: https://travis-ci.org/jaraco/jaraco.collections

.. .. image:: https://img.shields.io/appveyor/ci/jaraco/skeleton/master.svg
..    :target: https://ci.appveyor.com/project/jaraco/skeleton/branch/master

.. image:: https://readthedocs.org/projects/jaracocollections/badge/?version=latest
   :target: https://jaracocollections.readthedocs.io/en/latest/?badge=latest

Models and classes to supplement the stdlib 'collections' module.

RangeMap
--------

A dictionary-like object that maps a range of values to a given value.
